@@ -1,18 +1,20 @@
 """Test `django_fido.models`."""
 import base64
 import json
+from typing import cast
 
 from django.core.exceptions import ValidationError
 from django.test import SimpleTestCase, TestCase
 from fido2.cose import ES256
-from fido2.webauthn import AttestationObject, AuthenticatorData
+from fido2.webauthn import AttestationObject, AttestedCredentialData, AuthenticatorData
 
 from django_fido.constants import AuthLevel, AuthVulnerability
 from django_fido.models import Authenticator, AuthenticatorMetadata, TransportsValidator
 
-from .data import (ATTESTATION_OBJECT, ATTESTATION_OBJECT_AAGUID, ATTESTATION_OBJECT_NO_ATTESTATION_HANDED,
-                   ATTESTATION_OBJECT_U2F, ATTESTATION_OBJECT_U2F_NO_EXT, CREDENTIAL_ID, DETAILED_METADATA,
-                   DETAILED_METADATA_ATTESTATION_KEYS, DETAILED_METADATA_ATTESTATION_KEYS_NO_EXT,
+from .data import (ATTESTATION_OBJECT, ATTESTATION_OBJECT_AAGUID, ATTESTATION_OBJECT_DIRECT_CERT,
+                   ATTESTATION_OBJECT_NO_ATTESTATION_HANDED, ATTESTATION_OBJECT_U2F, ATTESTATION_OBJECT_U2F_NO_EXT,
+                   CREDENTIAL_ID, DETAILED_METADATA, DETAILED_METADATA_ATTESTATION_KEYS,
+                   DETAILED_METADATA_ATTESTATION_KEYS_NO_EXT, DETAILED_METADATA_DIRECT_CERT,
                    DETAILED_METADATA_WRONG_CERT)
 
 
@@ -81,10 +83,10 @@ class TestAuthenticator(SimpleTestCase):
 
     def test_credential_getter(self):
         authenticator = Authenticator(attestation_data=ATTESTATION_OBJECT)
-
-        self.assertEqual(authenticator.credential.aaguid, b'\0' * 16)
-        self.assertEqual(authenticator.credential.credential_id, base64.b64decode(CREDENTIAL_ID))
-        self.assertIsInstance(authenticator.credential.public_key, ES256)
+        credential = cast(AttestedCredentialData, authenticator.credential)
+        self.assertEqual(credential.aaguid, b'\0' * 16)
+        self.assertEqual(credential.credential_id, base64.b64decode(CREDENTIAL_ID))
+        self.assertIsInstance(credential.public_key, ES256)
 
     def test_attestation_getter(self):
         authenticator = Authenticator(attestation_data=ATTESTATION_OBJECT)
@@ -185,6 +187,14 @@ class TestAuthenticatorDatabase(TestCase):
         authenticator = Authenticator(attestation_data=ATTESTATION_OBJECT_NO_ATTESTATION_HANDED)
         self.assertIsNone(authenticator.metadata)
 
+    def test_metadata_direct_device_cert(self):
+        status = {'statusReports': [{'status': 'FIDO_CERTIFIED'}],
+                  'metadataStatement': DETAILED_METADATA_DIRECT_CERT}
+        metadata = AuthenticatorMetadata.objects.create(identifier='998f358b-2dd2-4cbe-a43a-e8107438dfb3',
+                                                        detailed_metadata_entry='', metadata_entry=json.dumps(status))
+        authenticator = Authenticator(attestation_data=ATTESTATION_OBJECT_DIRECT_CERT)
+        self.assertEqual(authenticator.metadata, metadata)
+
 
 class TestAuthenticatorMetadata(TestCase):
     """Unittests for AuthenticatorMetadata model."""
