@@ -1,12 +1,14 @@
 """Test `django_fido.views` module."""
 import base64
 import json
+from unittest.mock import patch
 
 from django.contrib.auth import get_user, get_user_model
 from django.core.exceptions import NON_FIELD_ERRORS
 from django.test import TestCase, override_settings
 from django.urls import reverse, reverse_lazy
 from fido2.utils import websafe_decode
+from fido2.webauthn import UserVerificationRequirement
 
 from django_fido.constants import AUTHENTICATION_USER_SESSION_KEY, FIDO2_REQUEST_SESSION_KEY
 from django_fido.models import Authenticator
@@ -17,11 +19,6 @@ from .data import (ATTESTATION_OBJECT, ATTESTATION_OBJECT_BOGUS, ATTESTATION_OBJ
                    USER_FULL_NAME, USER_HANDLE, USER_HANDLE_B64, USER_LAST_NAME, USERNAME)
 from .utils import TEMPLATES
 
-try:
-    from fido2.webauthn import UserVerificationRequirement
-except ImportError:
-    from fido2.server import USER_VERIFICATION as UserVerificationRequirement
-
 User = get_user_model()
 
 
@@ -40,7 +37,7 @@ class TestFido2RegistrationRequestView(TestCase):
 
         self.assertRedirects(response, '/login/?next={}'.format(self.url), fetch_redirect_response=False)
 
-    def _get_fido2_request(self, challenge, credentials):
+    def _get_fido2_request(self, challenge, credentials, *, resident=False):
         credential_params = [{'alg': -7, 'type': 'public-key'}, {'alg': -8, 'type': 'public-key'},
                              {'alg': -35, 'type': 'public-key'}, {'alg': -36, 'type': 'public-key'},
                              {'alg': -37, 'type': 'public-key'}, {'alg': -257, 'type': 'public-key'}]
@@ -50,12 +47,20 @@ class TestFido2RegistrationRequestView(TestCase):
         }
         fido2_request = {'publicKey': {
             'rp': rp_data,
-            'user': {'displayName': USER_FULL_NAME, 'id': USERNAME, 'name': USERNAME},
+            'user': {
+                'displayName': USER_FULL_NAME,
+                'id': base64.b64encode(bytes(USERNAME, encoding="utf-8")).decode("utf-8"),
+                'name': USERNAME
+            },
             'challenge': base64.b64encode(challenge).decode('utf-8'),
             'pubKeyCredParams': credential_params,
             'attestation': 'none',
             'excludeCredentials': credentials,
         }}
+        if resident:
+            fido2_request['publicKey']['authenticatorSelection'] = {'requireResidentKey': True,
+                                                                    'residentKey': 'required'}
+            fido2_request['publicKey']['user']['id'] = 'AA=='
         return fido2_request
 
     def test_get(self):
@@ -69,6 +74,20 @@ class TestFido2RegistrationRequestView(TestCase):
         challenge = websafe_decode(state['challenge'])
         self.assertEqual(response.json(), self._get_fido2_request(challenge, []))
 
+    @override_settings(DJANGO_FIDO_RESIDENT_KEY=True)
+    def test_get_resident(self):
+        self.client.force_login(self.user)
+
+        with patch('django_fido.views.uuid') as uuid_mock:
+            uuid_mock.uuid4.bytes.return_value = b'somebytes'
+            response = self.client.get(self.url)
+
+        self.assertEqual(response.status_code, 200)
+        # Check response
+        state = self.client.session[FIDO2_REQUEST_SESSION_KEY]
+        challenge = websafe_decode(state['challenge'])
+        self.assertEqual(response.json(), self._get_fido2_request(challenge, [], resident=True))
+
     def test_get_registered_keys(self):
         Authenticator.objects.create(user=self.user, attestation_data=ATTESTATION_OBJECT)
         self.client.force_login(self.user)
